Oslo Messaging Library
======================

.. image:: https://img.shields.io/pypi/v/oslo.messaging.svg
    :target: https://pypi.python.org/pypi/oslo.messaging/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/oslo.messaging.svg
    :target: https://pypi.python.org/pypi/oslo.messaging/
    :alt: Downloads

The Oslo messaging API supports RPC and notifications over a number of
different messaging transports.

* License: Apache License, Version 2.0
* Documentation: http://docs.openstack.org/developer/oslo.messaging
* Source: http://git.openstack.org/cgit/openstack/oslo.messaging
* Bugs: http://bugs.launchpad.net/oslo.messaging
